use reqwest::Error as ReqwestError;
use std::fmt;

#[derive(Debug)]
pub enum PlayerError {
    UserAlreadyExists(String),
    RequestError(ReqwestError),
    Other(String),
}

impl fmt::Display for PlayerError {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        match self {
            PlayerError::UserAlreadyExists(name) => write!(f, "Пользователь с именем '{}' уже существует", name),
            PlayerError::RequestError(err) => write!(f, "Ошибка запроса: {}", err),
            PlayerError::Other(msg) => write!(f, "Ошибка: {}", msg),
        }
    }
}

impl From<ReqwestError> for PlayerError {
    fn from(err: ReqwestError) -> PlayerError {
        PlayerError::RequestError(err)
    }
}